@@ -1,7 +1,7 @@
 package TableData::Object::aoaos;
 
-our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2017-01-01'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -192,6 +192,57 @@ sub switch_cols {
     }
 }
 
+sub add_col {
+    my ($self, $name, $idx, $spec) = @_;
+
+    die "Column '$name' already exists" if defined $self->col_name($name);
+    my $col_count = $self->col_count;
+    if (defined $idx) {
+        die "Index must be between 0..$col_count"
+            unless $idx >= 0 && $idx <= $col_count;
+    } else {
+        $idx = $col_count;
+    }
+
+    for (keys %{ $self->{cols_by_name} }) {
+        $self->{cols_by_name}{$_}++ if $self->{cols_by_name}{$_} >= $idx;
+    }
+    $self->{cols_by_name}{$name} = $idx;
+    splice @{ $self->{cols_by_idx} }, $idx, 0, $name;
+    if ($self->{spec}) {
+        my $ff = $self->{spec}{fields};
+        for my $f (values %$ff) {
+            $f->{pos}++ if defined($f->{pos}) && $f->{pos} >= $idx;
+        }
+        $ff->{$name} = defined($spec) ? {%$spec} : {};
+        $ff->{$name}{pos} = $idx;
+    }
+
+    for my $row (@{ $self->{data} }) {
+        splice @$row, $idx, 0, undef;
+    }
+}
+
+sub set_col_val {
+    my ($self, $name_or_idx, $value_sub) = @_;
+
+    my $col_name = $self->col_name($name_or_idx);
+    my $col_idx  = $self->col_idx($name_or_idx);
+
+    die "Column '$name_or_idx' does not exist" unless defined $col_name;
+
+    for my $i (0..$#{ $self->{data} }) {
+        my $row = $self->{data}[$i];
+        $row->[$col_idx] = $value_sub->(
+            table    => $self,
+            row_idx  => $i,
+            col_name => $col_name,
+            col_idx  => $col_idx,
+            value    => $row->[$col_idx],
+        );
+    }
+}
+
 1;
 # ABSTRACT: Manipulate array of arrays-of-scalars via table object
 
@@ -207,7 +258,7 @@ TableData::Object::aoaos - Manipulate array of arrays-of-scalars via table objec
 
 =head1 VERSION
 
-This document describes version 0.09 of TableData::Object::aoaos (from Perl distribution TableData-Object), released on 2016-01-13.
+This document describes version 0.10 of TableData::Object::aoaos (from Perl distribution TableData-Object), released on 2016-01-01.
 
 =head1 SYNOPSIS
 
@@ -258,7 +309,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
