@@ -1,7 +1,7 @@
 package TableData::Object::hash;
 
-our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2017-01-01'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -74,7 +74,51 @@ sub const_col_names {
 }
 
 sub switch_cols {
-    die "Cannot switch column in aos table";
+    die "Cannot switch column in hash table";
+}
+
+sub add_col {
+    die "Cannot add_col in hash table";
+}
+
+sub set_col_val {
+    my ($self, $name_or_idx, $value_sub) = @_;
+
+    my $col_name = $self->col_name($name_or_idx);
+    my $col_idx  = $self->col_idx($name_or_idx);
+
+    die "Column '$name_or_idx' does not exist" unless defined $col_name;
+
+    my $hash = $self->{data};
+    if ($col_name eq 'key') {
+        my $row_idx = -1;
+        for my $key (sort keys %$hash) {
+            $row_idx++;
+            my $new_key = $value_sub->(
+                table    => $self,
+                row_idx  => $row_idx,
+                row_name => $key,
+                col_name => $col_name,
+                col_idx  => $col_idx,
+                value    => $hash->{$key},
+            );
+            $hash->{$new_key} = delete $hash->{$key}
+                unless $key eq $new_key;
+        }
+    } else {
+        my $row_idx = -1;
+        for my $key (sort keys %$hash) {
+            $row_idx++;
+            $hash->{$key} = $value_sub->(
+                table    => $self,
+                row_idx  => $row_idx,
+                row_name => $key,
+                col_name => $col_name,
+                col_idx  => $col_idx,
+                value    => $hash->{$key},
+            );
+        }
+    }
 }
 
 1;
@@ -92,7 +136,7 @@ TableData::Object::hash - Manipulate hash via table object
 
 =head1 VERSION
 
-This document describes version 0.09 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2016-01-13.
+This document describes version 0.10 of TableData::Object::hash (from Perl distribution TableData-Object), released on 2016-01-01.
 
 =head1 SYNOPSIS
 
@@ -142,7 +186,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
